@@ -48,6 +48,20 @@ class ETreeOnlyTestCase(HelperTestCase):
         self.assertEquals("TEST", root.get("attr"))
         self.assertRaises(TypeError, root.set, "newattr", 5)
 
+    def test_parse_file_dtd(self):
+        parse = self.etree.parse
+        parser = self.etree.XMLParser(attribute_defaults=True)
+
+        tree = parse(fileInTestDir('test.xml'), parser)
+        root = tree.getroot()
+
+        self.assertEquals(
+            "valueA",
+            root.get("default"))
+        self.assertEquals(
+            "valueB",
+            root[0].get("default"))
+
     def test_parse_error(self):
         parse = self.etree.parse
         # from StringIO
@@ -559,13 +573,48 @@ class ETreeOnlyTestCase(HelperTestCase):
             etree.SubElement(e, 'a%s' % i)
 
         new_element = etree.Element("test")
+        new_element.text = "TESTTEXT"
+        new_element.tail = "TESTTAIL"
         child1 = e[1]
         e.replace(e[0], new_element)
         self.assertEquals(
             new_element, e[0])
+        self.assertEquals(
+            "TESTTEXT",
+            e[0].text)
+        self.assertEquals(
+            "TESTTAIL",
+            e[0].tail)
         self.assertEquals(
             child1, e[1])
 
+    def test_extend(self):
+        etree = self.etree
+        root = etree.Element('foo')
+        for i in range(3):
+            element = etree.SubElement(root, 'a%s' % i)
+            element.text = "text%d" % i
+            element.tail = "tail%d" % i
+
+        elements = []
+        for i in range(3):
+            new_element = etree.Element("test%s" % i)
+            new_element.text = "TEXT%s" % i
+            new_element.tail = "TAIL%s" % i
+            elements.append(new_element)
+
+        root.extend(elements)
+
+        self.assertEquals(
+            ["a0", "a1", "a2", "test0", "test1", "test2"],
+            [ el.tag for el in root ])
+        self.assertEquals(
+            ["text0", "text1", "text2", "TEXT0", "TEXT1", "TEXT2"],
+            [ el.text for el in root ])
+        self.assertEquals(
+            ["tail0", "tail1", "tail2", "TAIL0", "TAIL1", "TAIL2"],
+            [ el.tail for el in root ])
+
     def test_docinfo_public(self):
         etree = self.etree
         xml_header = '<?xml version="1.0" encoding="ascii"?>'
